@@ -12,13 +12,12 @@ import numpy as np
 from Bio import AlignIO, Phylo
 from Bio.Phylo.TreeConstruction import DistanceTreeConstructor, _DistanceMatrix
 from fuzzysearch.common import group_matches
-from matplotlib import colors, gridspec, patches, get_backend
+from matplotlib import colors, gridspec, patches
 from natsort import natsorted
 
 from .argument_parser import ask_user, get_args, print_args
 from .base import SeqData, count_uniq_seq, read_fastx
-from .find_ssrs import (find_ssrs, get_best_match_in_group_RepData, remove_gaps,
-                        unfold_rep_seq)
+from .find_ssrs import find_ssrs, get_longest_RepData, remove_gaps, unfold_rep_seq
 from .utils import make_blastdb, run_mafft
 from .variant_filter import pairwise_dist_Levenstein
 
@@ -30,7 +29,7 @@ class AlleleCheck(object):
         outdir=None,
         force_no_visual_check=False,
         quiet=False,
-        **kwargs
+        **kwargs,
     ):
 
         self.infile = None
@@ -160,11 +159,14 @@ class AlleleCheck(object):
                     )
 
                     # add rep_data to seqdat
-                    self.add_rep_data
+                    self.add_rep_data()
 
-                    self.tree = construct_tree(
-                        self.align, self.ssr_regions, self.motifs
-                    )
+                    if len(self.align) > 1:
+                        self.tree = construct_tree(
+                            self.align, self.ssr_regions, self.motifs
+                        )
+                    else:
+                        self.tree = None
                     print("Reconstructing phylogeny ...")
             else:
                 msg = "Keep all sequences and write results?"
@@ -264,7 +266,10 @@ class AlleleCheck(object):
         self.add_allele_id()
 
         # construct an allele tree
-        self.tree = construct_tree(self.align, self.ssr_regions, self.motifs)
+        if len(self.align) > 1:
+            self.tree = construct_tree(self.align, self.ssr_regions, self.motifs)
+        else:
+            self.tree = None
 
         # add lists of potential stutter sequences
         all_seqs = [s.seq for s in self.seqdat]
@@ -291,9 +296,13 @@ class VisualAlleleCheck(object):
     """
 
     def __init__(self, seqdat, align, tree, ssr_regions, motifs, suptitle="", **kwargs):
-        self.order = [
-            int(c.name.split("_")[-1].replace("seq", "")) for c in tree.get_terminals()
-        ]
+        if tree:
+            self.order = [
+                int(c.name.split("_")[-1].replace("seq", ""))
+                for c in tree.get_terminals()
+            ]
+        else:
+            self.order = list(range(len(seqdat)))
         self.text_list = []
         for o in self.order:
             s = seqdat[o]
@@ -341,8 +350,9 @@ class VisualAlleleCheck(object):
         self.ax0.set_axis_off()
 
         # phylogeny
-        Phylo.draw(tree, do_show=False, axes=self.ax1, label_func=lambda x: None)
-        self.ax1.set_xlim((0, max(list(tree.depths().values()))))
+        if tree:
+            Phylo.draw(tree, do_show=False, axes=self.ax1, label_func=lambda x: None)
+            self.ax1.set_xlim((0, max(list(tree.depths().values()))))
 
         # sequence alignment
         align_arr = np.array(align)[self.order, :]
@@ -392,7 +402,7 @@ class VisualAlleleCheck(object):
         self.ax2.set_xticks(np.arange(0, n, 20))
         self.ax2.set_yticks(np.arange(1, m + 3))
         self.ytl2 = [re.sub("^.*\\*", "*", seqdat[o].id) for o in self.order] + [
-            "varible site",
+            "variable site",
             "SSR region",
         ]
         self.ax2.set_yticklabels(self.ytl2)
@@ -515,8 +525,8 @@ class VisualAlleleCheck(object):
 
     def show_info(self, idx):
         if idx == -1:
-            s = u"Left click on a sequence  (or press \u2191/\u2193 key) to "
-            s += u"show information \n right click (or press \u2190/\u2192"
+            s = "Left click on a sequence  (or press \u2191/\u2193 key) to "
+            s += "show information \n right click (or press \u2190/\u2192"
             s += r" key) to select the sequence to $\bf{discard}$"
             self.txt0 = self.ax0.text(
                 0.5, 0.6, s=s, color="grey", va="center", ha="center", wrap=True
@@ -726,7 +736,7 @@ def find_variable_ssrs(align, min_variants=3, **kwargs):
         if len(group) >= min_variants:
             starts, ends = list(zip(*[[rep.start, rep.end] for rep in group]))
             ssr_regions.append((np.min(starts), np.max(ends)))
-            motifs.append(get_best_match_in_group_RepData(group).motif)
+            motifs.append(get_longest_RepData(group).motif)
 
     return ssr_regions, motifs
 
@@ -750,7 +760,7 @@ def characterise_ssrs(align, ssr_region, motif, max_interrupt=None):
                 end=ssr_region_ng[-1],
                 max_interrupt=len(motif),
             )
-            best = get_best_match_in_group_RepData(rep)
+            best = get_longest_RepData(rep)
             reps.append(best)
         else:
             reps.append(None)
